### Barrier3D v1.0

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4730989.svg)](https://doi.org/10.5281/zenodo.4730989)



Note: [Barrier3D v2.0](https://github.com/UNC-CECL/Barrier3D/tree/Barrier3d-v2.0) is built with the [Basic Model Interface](https://bmi.readthedocs.io/).


`Barrier3D.py` is the main runfile for individual simulations.

`Barrier3D_Functions.py` contains functions for running simulations and plotting results.

`Barrier3D_Parameters.py` sets parameter values and initial conditions for simulations.

__`/Parameterization`__ contains storm, dune, and elevation parameter files needed to run Barrier3D.

__`/Scripts`__ contains code for creating new storm and dune parameter files and for presenting results from multiple simulations.

__`/Batch`__ holds versions of the model for running batches of simulations across ranges of parameter values.
